@@ -1,17 +1,16 @@
 #!/usr/bin/python3
 # -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
 
-import apt
 import apt_pkg
-import hashlib
 import mock
 import os
 import unittest
-import shutil
 import tempfile
 import json
 
+from mock import patch
 from DistUpgrade.DistUpgradeQuirks import DistUpgradeQuirks
+from DistUpgrade.RiscvProfile import RiscvProfile
 
 CURDIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -172,76 +171,6 @@ def make_mock_pkg(name, is_installed, candidate_rec=""):
     return mock_pkg
 
 
-class TestPatches(unittest.TestCase):
-
-    orig_chdir = ''
-
-    def setUp(self):
-        # To patch, we need to be in the same directory as the patched files
-        self.orig_chdir = os.getcwd()
-        os.chdir(CURDIR)
-
-    def tearDown(self):
-        os.chdir(self.orig_chdir)
-
-    def _verify_result_checksums(self):
-        """ helper for test_patch to verify that we get the expected result """
-        # simple case is foo
-        patchdir = CURDIR + "/patchdir/"
-        with open(patchdir + "foo") as f:
-            self.assertFalse("Hello" in f.read())
-        with open(patchdir + "foo_orig") as f:
-            self.assertTrue("Hello" in f.read())
-        md5 = hashlib.md5()
-        with open(patchdir + "foo", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "52f83ff6877e42f613bcd2444c22528c")
-        # more complex example fstab
-        md5 = hashlib.md5()
-        with open(patchdir + "fstab", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "c56d2d038afb651920c83106ec8dfd09")
-        # most complex example
-        md5 = hashlib.md5()
-        with open(patchdir + "pycompile", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "97c07a02e5951cf68cb3f86534f6f917")
-        # with ".\n"
-        md5 = hashlib.md5()
-        with open(patchdir + "dotdot", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "cddc4be46bedd91db15ddb9f7ddfa804")
-        # test that incorrect md5sum after patching rejects the patch
-        with open(patchdir + "fail") as f1, open(patchdir + "fail_orig") as f2:
-            self.assertEqual(f1.read(),
-                             f2.read())
-
-    def test_patch(self):
-        q = DistUpgradeQuirks(MockController(), MockConfig)
-        # create patch environment
-        patchdir = CURDIR + "/patchdir/"
-        shutil.copy(patchdir + "foo_orig", patchdir + "foo")
-        shutil.copy(patchdir + "fstab_orig", patchdir + "fstab")
-        shutil.copy(patchdir + "pycompile_orig", patchdir + "pycompile")
-        shutil.copy(patchdir + "dotdot_orig", patchdir + "dotdot")
-        shutil.copy(patchdir + "fail_orig", patchdir + "fail")
-        # apply patches
-        q._applyPatches(patchdir=patchdir)
-        self._verify_result_checksums()
-        # now apply patches again and ensure we don't patch twice
-        q._applyPatches(patchdir=patchdir)
-        self._verify_result_checksums()
-
-    def test_patch_lowlevel(self):
-        # test lowlevel too
-        from DistUpgrade.DistUpgradePatcher import patch, PatchError
-        self.assertRaises(PatchError, patch, CURDIR + "/patchdir/fail",
-                          CURDIR + "/patchdir/patchdir_fail."
-                          "ed04abbc6ee688ee7908c9dbb4b9e0a2."
-                          "deadbeefdeadbeefdeadbeff",
-                          "deadbeefdeadbeefdeadbeff")
-
-
 class TestQuirks(unittest.TestCase):
 
     orig_recommends = ''
@@ -273,39 +202,6 @@ class TestQuirks(unittest.TestCase):
         q.ensure_recommends_are_installed_on_desktops()
         self.assertTrue(apt_pkg.config.find_b("APT::Install-Recommends"))
 
-    def test_parse_from_modaliases_header(self):
-        pkgrec = {
-            "Package": "foo",
-            "Modaliases": "modules1(pci:v00001002d00006700sv*sd*bc03sc*i*, "
-                          "pci:v00001002d00006701sv*sd*bc03sc*i*), "
-                          "module2(pci:v00001002d00006702sv*sd*bc03sc*i*, "
-                          "pci:v00001001d00006702sv*sd*bc03sc*i*)"
-        }
-        controller = mock.Mock()
-        config = mock.Mock()
-        q = DistUpgradeQuirks(controller, config)
-        self.assertEqual(q._parse_modaliases_from_pkg_header({}), [])
-        self.assertEqual(q._parse_modaliases_from_pkg_header(pkgrec),
-                         [("modules1",
-                           ["pci:v00001002d00006700sv*sd*bc03sc*i*",
-                            "pci:v00001002d00006701sv*sd*bc03sc*i*"]),
-                          ("module2",
-                           ["pci:v00001002d00006702sv*sd*bc03sc*i*",
-                            "pci:v00001001d00006702sv*sd*bc03sc*i*"])])
-
-    def disabled__as_fglrx_is_gone_testFglrx(self):
-        mock_lspci_good = set(['1002:9990'])
-        mock_lspci_bad = set(['8086:ac56'])
-        config = mock.Mock()
-        cache = apt.Cache()
-        controller = mock.Mock()
-        controller.cache = cache
-        q = DistUpgradeQuirks(controller, config)
-        if q.arch not in ['i386', 'amd64']:
-            return self.skipTest("Not on an arch with fglrx package")
-        self.assertTrue(q._supportInModaliases("fglrx", mock_lspci_good))
-        self.assertFalse(q._supportInModaliases("fglrx", mock_lspci_bad))
-
     def test_screensaver_poke(self):
         # fake nothing is installed
         empty_status = tempfile.NamedTemporaryFile()
@@ -436,16 +332,6 @@ class TestQuirks(unittest.TestCase):
         self.assertFalse(len(mock_question.mock_calls))
         self.assertFalse(len(mock_controller.abort.mock_calls))
 
-    @mock.patch('os.path.exists')
-    def test_aufs_fail(self, mock_exists):
-        mock_exists.return_value = True
-        mock_controller = mock.Mock()
-
-        q = DistUpgradeQuirks(mock_controller, mock.Mock())
-
-        q._test_and_fail_on_aufs()
-        self.assertTrue(len(mock_controller.abort.mock_calls))
-
     def test_replace_fkms_overlay_no_config(self):
         with tempfile.TemporaryDirectory() as boot_dir:
             mock_controller = mock.Mock()
@@ -601,228 +487,124 @@ max_framebuffers=2
             with open(os.path.join(boot_dir, 'config.txt')) as f:
                 self.assertTrue(f.read() == expected_config_txt)
 
-    def test_remove_uboot_no_config(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
+    def test_disable_kdump_tools_on_install(self):
+        """Test kdump-tools disabled if installed on upgrade."""
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
 
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
+        mock_pkg = make_mock_pkg(name="kdump-tools", is_installed=False)
+        mock_pkg.marked_install = True
+        mock_cache = {'kdump-tools': mock_pkg}
 
-    def test_remove_uboot_no_changes(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            native_config = """\
-# This is a demo boot config with a comment at the start that should not
-# be removed
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
 
-[pi4]
-max_framebuffers=2
+        expected_cmd = 'echo "kdump-tools kdump-tools/use_kdump boolean false"'
+        expected_cmd += ' | debconf-set-selections'
+        popen_mock.assert_called_once_with(expected_cmd, shell=True)
 
-[all]
-arm_64bit=1
-kernel=vmlinuz
-initramfs initrd.img followkernel
+    def test_no_disable_kdump_tools_if_installed(self):
+        """Test kdump-tools is not disabled on upgrade if already installed."""
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
 
-# This is a user-added include that should not be merged
-include custom.txt
-"""
-            custom_config = """\
-# This is the custom included configuration file
+        mock_pkg = make_mock_pkg(name="kdump-tools", is_installed=True)
+        mock_pkg.marked_install = True
+        mock_cache = {'kdump-tools': mock_pkg}
 
-hdmi_group=1
-hdmi_mode=4
-"""
-            with open(os.path.join(boot_dir, 'config.txt'), 'w') as f:
-                f.write(native_config)
-            with open(os.path.join(boot_dir, 'custom.txt'), 'w') as f:
-                f.write(custom_config)
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
 
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
+        popen_mock.assert_not_called()
 
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'custom.txt.distUpgrade')))
-            with open(os.path.join(boot_dir, 'config.txt')) as f:
-                self.assertTrue(f.read() == native_config)
-            with open(os.path.join(boot_dir, 'custom.txt')) as f:
-                self.assertTrue(f.read() == custom_config)
+    def test_no_disable_kdump_tools_if_not_requested(self):
+        """Test kdump-tools disable hook does nothing if not requested."""
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
 
-    def test_remove_uboot_with_changes(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            config_txt = """\
-# This is a warning that you should not edit this file. The upgrade should
-# remove this comment
+        # Do nothing if not found in cache
+        mock_cache = {}
 
-[pi4]
-# This is a comment that should be included
-kernel=uboot_rpi_4.bin
-max_framebuffers=2
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
 
-[pi2]
-kernel=uboot_rpi_2.bin
+        popen_mock.assert_not_called()
 
-[pi3]
-kernel=uboot_rpi_3.bin
+        # Do nothing if not requested for install
+        mock_pkg = make_mock_pkg(name="kdump-tools", is_installed=False)
+        mock_pkg.marked_install = False
+        mock_cache = {'kdump-tools': mock_pkg}
 
-[all]
-arm_64bit=1
-device_tree_address=0x3000000
-include syscfg.txt
-include usercfg.txt
-dtoverlay=vc4-fkms-v3d,cma-256
-include custom.txt
-"""
-            usercfg_txt = """\
-# Another chunk of warning text that should be skipped
-"""
-            syscfg_txt = """\
-# Yet more warnings to exclude
-dtparam=audio=on
-dtparam=spi=on
-enable_uart=1
-"""
-            custom_txt = """\
-# This is a user-added file that should be left alone by the upgrade
-[gpio4=1]
-kernel=custom
-"""
-            expected_config_txt = """\
+        with mock.patch(
+            "DistUpgrade.DistUpgradeQuirks.subprocess.run"
+        ) as popen_mock:
+            q._disable_kdump_tools_on_install(mock_cache)
 
-[pi4]
-# This is a comment that should be included
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_4.bin
-max_framebuffers=2
+        popen_mock.assert_not_called()
 
-[pi2]
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_2.bin
+    def test_test_and_fail_on_rva23(self):
+        """
+        Unit test for DistUpgradeQuirks.test_and_fail_on_rva23
 
-[pi3]
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_3.bin
+        Expect abort for system not complying with RVA23U64.
+        Expect no abort for compliant sytem.
+        """
 
-[all]
-# added by do-release-upgrade (LP: #1936401)
-kernel=vmlinuz
-initramfs initrd.img followkernel
-arm_64bit=1
-# commented by do-release-upgrade (LP: #1936401)
-#device_tree_address=0x3000000
-# merged from syscfg.txt by do-release-upgrade (LP: #1936401)
-dtparam=audio=on
-dtparam=spi=on
-enable_uart=1
-# merged from usercfg.txt by do-release-upgrade (LP: #1936401)
-dtoverlay=vc4-fkms-v3d,cma-256
-include custom.txt
-"""
-            with open(os.path.join(boot_dir, 'config.txt'), 'w') as f:
-                f.write(config_txt)
-            with open(os.path.join(boot_dir, 'syscfg.txt'), 'w') as f:
-                f.write(syscfg_txt)
-            with open(os.path.join(boot_dir, 'usercfg.txt'), 'w') as f:
-                f.write(usercfg_txt)
-            with open(os.path.join(boot_dir, 'custom.txt'), 'w') as f:
-                f.write(custom_txt)
+        # All RVA23U64 mandatory extensions
+        good_cpu_info = RiscvProfile(
+               'rv64imafdcbv_zic64b_zicbom_zicbop_zicboz_ziccamoa_ziccif_'
+               'zicclsm_ziccrse_zicntr_zicond_zicsr_zihintntl_'
+               'zihintpause_zihpm_zimop_za64rs_zawrs_zfa_zfhmin_zcb_'
+               'zcmop_zvbb_zvfhmin_zvkt_zkt_supm')
 
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
+        # Vector support missing
+        bad_cpu_info = RiscvProfile(
+               'rv64imafdcb_zic64b_zicbom_zicbop_zicboz_ziccamoa_ziccif_'
+               'zicclsm_ziccrse_zicntr_zicond_zicsr_zihintntl_'
+               'zihintpause_zihpm_zimop_za64rs_zawrs_zfa_zfhmin_zcb_'
+               'zcmop_zkt_supm')
 
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'syscfg.txt.distUpgrade')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'usercfg.txt.distUpgrade')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'config.txt')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'custom.txt')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'syscfg.txt')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'usercfg.txt')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'custom.txt.distUpgrade')))
-            with open(os.path.join(boot_dir, 'config.txt')) as f:
-                self.assertTrue(f.read() == expected_config_txt)
-            with open(os.path.join(boot_dir, 'custom.txt')) as f:
-                self.assertTrue(f.read() == custom_txt)
+        mock_controller = mock.Mock()
+        q = DistUpgradeQuirks(mock_controller, mock.Mock())
 
-    def test_remove_uboot_no_all_section(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            config_txt = """\
-arm_64bit=1
-device_tree_address=0x3000000
+        with patch.object(RiscvProfile,
+                          'read_cpuinfo') as mock_cpuinfo:
+            mock_cpuinfo.return_value = good_cpu_info
+            mock_question = mock_controller._view.askYesNoQuestion
+            mock_question.return_value = False
+            q._test_and_fail_on_rva23()
+            self.assertEqual(0, len(mock_controller.abort.mock_calls))
 
-[pi4]
-# This is a comment that should be included
-kernel=uboot_rpi_4.bin
-max_framebuffers=2
+        with patch.object(RiscvProfile,
+                          'read_cpuinfo') as mock_cpuinfo:
+            mock_cpuinfo.return_value = bad_cpu_info
+            mock_question = mock_controller._view.askYesNoQuestion
+            mock_question.return_value = True
+            q._test_and_fail_on_rva23()
+            self.assertEqual(0, len(mock_controller.abort.mock_calls))
 
-[pi3]
-kernel=uboot_rpi_3.bin
-"""
-            expected_config_txt = """\
-arm_64bit=1
-# commented by do-release-upgrade (LP: #1936401)
-#device_tree_address=0x3000000
-
-[pi4]
-# This is a comment that should be included
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_4.bin
-max_framebuffers=2
-
-[pi3]
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_3.bin
-# added by do-release-upgrade (LP: #1936401)
-[all]
-kernel=vmlinuz
-initramfs initrd.img followkernel
-"""
-            with open(os.path.join(boot_dir, 'config.txt'), 'w') as f:
-                f.write(config_txt)
-
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
-
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
-            with open(os.path.join(boot_dir, 'config.txt')) as f:
-                self.assertTrue(f.read() == expected_config_txt)
+        with patch.object(RiscvProfile,
+                          'read_cpuinfo') as mock_cpuinfo:
+            mock_cpuinfo.return_value = bad_cpu_info
+            mock_question = mock_controller._view.askYesNoQuestion
+            mock_question.return_value = False
+            q._test_and_fail_on_rva23()
+            self.assertEqual(1, len(mock_controller.abort.mock_calls))
 
 
 class TestSnapQuirks(unittest.TestCase):
 
-    def test_get_from_and_to_version(self):
-        # Prepare the state for testing
-        controller = mock.Mock()
-        controller.fromDist = 'disco'
-        controller.toDist = 'eoan'
-        config = mock.Mock()
-        q = DistUpgradeQuirks(controller, config)
-        # Call method under test
-        q._get_from_and_to_version()
-        self.assertEqual(q._from_version, '19.04')
-        self.assertEqual(q._to_version, '19.10')
-
     @mock.patch("subprocess.Popen", MockPopenSnap)
     def test_prepare_snap_replacement_data(self):
         # Prepare the state for testing
         controller = mock.Mock()
         config = mock.Mock()
+        controller.fromVersion = '24.04'
+        controller.toVersion = '24.10'
         q = DistUpgradeQuirks(controller, config)
-        q._from_version = "22.04"
-        q._to_version = "24.04"
         # Call method under test
 
         controller.cache = {
@@ -870,27 +652,36 @@ class TestSnapQuirks(unittest.TestCase):
         self.maxDiff = None
         self.assertDictEqual(
             q._snap_list,
-            {'core22': {
+            {'core24': {
                 'channel': 'stable',
                 'command': 'install',
                 'deb': None, 'snap-id': '1234'},
-             'gnome-42-2204': {
-                'channel': 'stable/ubuntu-24.04',
+             'gnome-46-2404': {
+                'channel': 'stable/ubuntu-24.10',
                 'command': 'install',
                 'deb': None, 'snap-id': '1234'},
+             'mesa-2404': {
+                'channel': 'stable/ubuntu-24.10',
+                'command': 'install',
+                'deb': None,
+                'snap-id': '1234'},
              'snap-store': {
-                'channel': '2/stable/ubuntu-24.04',
+                'channel': '2/stable/ubuntu-24.10',
                 'command': 'install',
                 'deb': 'gnome-software',
-                'snap-id': '1234'}})
+                'snap-id': '1234'},
+             'thunderbird': {
+                'channel': 'stable/ubuntu-24.10',
+                'command': 'install',
+                'deb': None,
+                'snap-id': '1234'}}
+        )
 
     def test_is_deb2snap_metapkg_installed(self):
         # Prepare the state for testing
         controller = mock.Mock()
         config = mock.Mock()
         q = DistUpgradeQuirks(controller, config)
-        q._from_version = "19.04"
-        q._to_version = "19.10"
         controller.cache = {
             'ubuntu-desktop':
                 make_mock_pkg(
@@ -913,13 +704,81 @@ class TestSnapQuirks(unittest.TestCase):
                              data[1],
                              'Expected {1} for input {0}'.format(*data))
 
-    @mock.patch("DistUpgrade.DistUpgradeQuirks.get_arch")
-    @mock.patch("urllib.request.urlopen")
-    def test_calculate_snap_size_requirements(self, urlopen, arch):
-        # Prepare the state for testing
-        arch.return_value = 'amd64'
+    def test_parse_deb2snap_json(self):
         controller = mock.Mock()
         config = mock.Mock()
+
+        q = DistUpgradeQuirks(controller, config)
+        q.controller.toVersion = '25.04'
+        q._is_deb2snap_metapkg_installed = mock.Mock()
+        q._is_deb2snap_metapkg_installed.return_value = True
+
+        for from_version in ('22.04', '22.10'):
+            q.controller.fromVersion = from_version
+
+            m = mock.mock_open(read_data=(
+                '{'
+                '  "seeded": {'
+                '    "test-snap-1": {'
+                '      "metapkg": "ubuntu-desktop-minimal",'
+                '      "from_channel": "latest/edge",'
+                '      "to_channel": "latest/stable"'
+                '    },'
+                '    "test-snap-2": {'
+                '      "deb": "test-deb-2",'
+                '      "metapkg": "ubuntu-desktop-minimal"'
+                '    },'
+                '    "test-snap-3": {'
+                '      "metapkg": "ubuntu-desktop-minimal",'
+                '      "force_switch": true,'
+                '      "from_channel": "1/stable/ubuntu-{FROM_VERSION}",'
+                '      "to_channel": "2/stable/ubuntu-{TO_VERSION}"'
+                '    }'
+                '  },'
+                '  "unseeded": {'
+                '  }'
+                '}'
+            ))
+
+            with mock.patch('DistUpgrade.DistUpgradeQuirks.open', m):
+                seeded, unseeded = q._parse_deb2snap_json()
+
+                self.assertEqual(unseeded, {})
+
+                self.assertEqual(
+                    seeded['test-snap-1'],
+                    (
+                        None,
+                        'latest/edge',
+                        'latest/stable',
+                        False
+                    )
+                )
+                self.assertEqual(
+                    seeded['test-snap-2'],
+                    (
+                        'test-deb-2',
+                        f'stable/ubuntu-{q.controller.fromVersion}',
+                        f'stable/ubuntu-{q.controller.toVersion}',
+                        False
+                    )
+                )
+                self.assertEqual(
+                    seeded['test-snap-3'],
+                    (
+                        None,
+                        f'1/stable/ubuntu-{q.controller.fromVersion}',
+                        f'2/stable/ubuntu-{q.controller.toVersion}',
+                        True
+                    )
+                )
+
+    @mock.patch("urllib.request.urlopen")
+    def test_calculate_snap_size_requirements(self, urlopen):
+        # Prepare the state for testing
+        controller = mock.Mock()
+        controller.arch = 'amd64'
+        config = mock.Mock()
         q = DistUpgradeQuirks(controller, config)
         # We mock out _prepare_snap_replacement_data(), as this is tested
         # separately.
@@ -935,7 +794,6 @@ class TestSnapQuirks(unittest.TestCase):
             'gnome-system-monitor': {'command': 'refresh',
                                      'channel': 'stable/ubuntu-19.10'}
         }
-        q._to_version = "19.10"
         # Mock out urlopen in such a way that we get a mocked response based
         # on the parameters given but also allow us to check call arguments
         # etc.
@@ -983,7 +841,6 @@ class TestSnapQuirks(unittest.TestCase):
                            'snap-id': '1234',
                            'channel': 'stable/ubuntu-19.10'}
         }
-        q._to_version = "19.10"
         q._replaceDebsAndSnaps()
         # Make sure all snaps have been handled
         self.assertEqual(run_mock.call_count, 8)
@@ -1022,66 +879,6 @@ class TestSnapQuirks(unittest.TestCase):
         # actual deb packages that will have to be removed during the upgrade
         self.assertEqual(controller.forced_obsoletes.append.call_count, 3)
 
-    @mock.patch("builtins.open", new_callable=mock.mock_open,
-                read_data="""\
-processor       : 0
-cpu             : POWER8 (raw), altivec supported
-clock           : 3491.000000MHz
-revision        : 2.0 (pvr 004d 0200)
-
-processor       : 1
-cpu             : POWER8 (raw), altivec supported
-clock           : 3491.000000MHz
-revision        : 2.0 (pvr 004d 0200)
-
-timebase        : 512000000
-platform        : PowerNV
-model           : 8001-22C
-machine         : PowerNV 8001-22C
-firmware        : OPAL
-MMU             : Hash
-""")
-    @mock.patch("DistUpgrade.DistUpgradeQuirks.get_arch",
-                return_value="ppc64el")
-    def test_power8_fail(self, arch, mock_file):
-        controller = mock.Mock()
-        config = mock.Mock()
-        q = DistUpgradeQuirks(controller, config)
-
-        q._test_and_fail_on_power8()
-        self.assertTrue(len(controller.abort.mock_calls))
-
-        mock_file.assert_called_with("/proc/cpuinfo")
-
-    def test_raspi_armhf_abort_upgrade(self):
-        for arch in ('armhf', 'arm64'):
-            with mock.patch(
-                'DistUpgrade.DistUpgradeQuirks.get_arch'
-            ) as mock_get_arch:
-
-                mock_get_arch.return_value = arch
-
-                controller = mock.Mock()
-                config = mock.Mock()
-                q = DistUpgradeQuirks(controller, config)
-                q.controller.fromDist = 'jammy'
-                q.controller.toDist = 'noble'
-                controller.cache = {
-                    'linux-image-raspi':
-                        make_mock_pkg(
-                            name='linux-image-raspi',
-                            is_installed=True,
-                        )
-                }
-
-                q._test_and_fail_on_armhf_raspi()
-
-                self.assertEqual(
-                    len(controller.abort.mock_calls),
-                    1 if arch == 'armhf' else 0,
-                    f'arch = {arch}',
-                )
-
 
 if __name__ == "__main__":
     import logging
